@@ -15,16 +15,15 @@
 
 import eventlet
 import mock
-
-from oslotest import base as test_base
 from testtools.matchers import HasLength
 
 from ironic_lib import disk_partitioner
 from ironic_lib import exception
+from ironic_lib.tests import base
 from ironic_lib import utils
 
 
-class DiskPartitionerTestCase(test_base.BaseTestCase):
+class DiskPartitionerTestCase(base.IronicLibTestCase):
 
     def test_add_partition(self):
         dp = disk_partitioner.DiskPartitioner('/dev/fake')
@@ -33,18 +32,22 @@ class DiskPartitionerTestCase(test_base.BaseTestCase):
         dp.add_partition(2048, boot_flag='boot')
         dp.add_partition(2048, boot_flag='bios_grub')
         expected = [(1, {'boot_flag': None,
+                         'extra_flags': None,
                          'fs_type': '',
                          'type': 'primary',
                          'size': 1024}),
                     (2, {'boot_flag': None,
+                         'extra_flags': None,
                          'fs_type': 'linux-swap',
                          'type': 'primary',
                          'size': 512}),
                     (3, {'boot_flag': 'boot',
+                         'extra_flags': None,
                          'fs_type': '',
                          'type': 'primary',
                          'size': 2048}),
                     (4, {'boot_flag': 'bios_grub',
+                         'extra_flags': None,
                          'fs_type': '',
                          'type': 'primary',
                          'size': 2048})]
@@ -58,20 +61,28 @@ class DiskPartitionerTestCase(test_base.BaseTestCase):
     def test_commit(self, mock_utils_exc, mock_disk_partitioner_exec):
         dp = disk_partitioner.DiskPartitioner('/dev/fake')
         fake_parts = [(1, {'boot_flag': None,
+                           'extra_flags': None,
                            'fs_type': 'fake-fs-type',
                            'type': 'fake-type',
                            'size': 1}),
                       (2, {'boot_flag': 'boot',
+                           'extra_flags': None,
                            'fs_type': 'fake-fs-type',
                            'type': 'fake-type',
                            'size': 1}),
                       (3, {'boot_flag': 'bios_grub',
+                           'extra_flags': None,
+                           'fs_type': 'fake-fs-type',
+                           'type': 'fake-type',
+                           'size': 1}),
+                      (4, {'boot_flag': 'boot',
+                           'extra_flags': ['prep', 'fake-flag'],
                            'fs_type': 'fake-fs-type',
                            'type': 'fake-type',
                            'size': 1})]
         with mock.patch.object(dp, 'get_partitions', autospec=True) as mock_gp:
             mock_gp.return_value = fake_parts
-            mock_utils_exc.return_value = (None, None)
+            mock_utils_exc.return_value = ('', '')
             dp.commit()
 
         mock_disk_partitioner_exec.assert_called_once_with(
@@ -80,9 +91,13 @@ class DiskPartitionerTestCase(test_base.BaseTestCase):
             'mkpart', 'fake-type', 'fake-fs-type', '2', '3',
             'set', '2', 'boot', 'on',
             'mkpart', 'fake-type', 'fake-fs-type', '3', '4',
-            'set', '3', 'bios_grub', 'on')
+            'set', '3', 'bios_grub', 'on',
+            'mkpart', 'fake-type', 'fake-fs-type', '4', '5',
+            'set', '4', 'boot', 'on', 'set', '4', 'prep', 'on',
+            'set', '4', 'fake-flag', 'on')
         mock_utils_exc.assert_called_once_with(
-            'fuser', '/dev/fake', run_as_root=True, check_exit_code=[0, 1])
+            'fuser', '/dev/fake', run_as_root=True,
+            check_exit_code=[0, 1])
 
     @mock.patch.object(eventlet.greenthread, 'sleep', lambda seconds: None)
     @mock.patch.object(disk_partitioner.DiskPartitioner, '_exec',
@@ -92,14 +107,17 @@ class DiskPartitionerTestCase(test_base.BaseTestCase):
                                              mock_disk_partitioner_exec):
         dp = disk_partitioner.DiskPartitioner('/dev/fake')
         fake_parts = [(1, {'boot_flag': None,
+                           'extra_flags': None,
                            'fs_type': 'fake-fs-type',
                            'type': 'fake-type',
                            'size': 1}),
                       (2, {'boot_flag': 'boot',
+                           'extra_flags': None,
                            'fs_type': 'fake-fs-type',
                            'type': 'fake-type',
                            'size': 1})]
-        fuser_outputs = iter([("/dev/fake: 10000 10001", None), (None, None)])
+        # Test as if the 'psmisc' version of 'fuser' which has stderr output
+        fuser_outputs = iter([(" 10000 10001", '/dev/fake:\n'), ('', '')])
 
         with mock.patch.object(dp, 'get_partitions', autospec=True) as mock_gp:
             mock_gp.return_value = fake_parts
@@ -112,7 +130,8 @@ class DiskPartitionerTestCase(test_base.BaseTestCase):
             'mkpart', 'fake-type', 'fake-fs-type', '2', '3',
             'set', '2', 'boot', 'on')
         mock_utils_exc.assert_called_with(
-            'fuser', '/dev/fake', run_as_root=True, check_exit_code=[0, 1])
+            'fuser', '/dev/fake', run_as_root=True,
+            check_exit_code=[0, 1])
         self.assertEqual(2, mock_utils_exc.call_count)
 
     @mock.patch.object(eventlet.greenthread, 'sleep', lambda seconds: None)
@@ -123,17 +142,21 @@ class DiskPartitionerTestCase(test_base.BaseTestCase):
                                                mock_disk_partitioner_exec):
         dp = disk_partitioner.DiskPartitioner('/dev/fake')
         fake_parts = [(1, {'boot_flag': None,
+                           'extra_flags': None,
                            'fs_type': 'fake-fs-type',
                            'type': 'fake-type',
                            'size': 1}),
                       (2, {'boot_flag': 'boot',
+                           'extra_flags': None,
                            'fs_type': 'fake-fs-type',
                            'type': 'fake-type',
                            'size': 1})]
 
         with mock.patch.object(dp, 'get_partitions', autospec=True) as mock_gp:
             mock_gp.return_value = fake_parts
-            mock_utils_exc.return_value = ("/dev/fake: 10000 10001", None)
+            # Test as if the 'busybox' version of 'fuser' which does not have
+            # stderr output
+            mock_utils_exc.return_value = ("10000 10001", '')
             self.assertRaises(exception.InstanceDeployFailure, dp.commit)
 
         mock_disk_partitioner_exec.assert_called_once_with(
@@ -142,7 +165,8 @@ class DiskPartitionerTestCase(test_base.BaseTestCase):
             'mkpart', 'fake-type', 'fake-fs-type', '2', '3',
             'set', '2', 'boot', 'on')
         mock_utils_exc.assert_called_with(
-            'fuser', '/dev/fake', run_as_root=True, check_exit_code=[0, 1])
+            'fuser', '/dev/fake', run_as_root=True,
+            check_exit_code=[0, 1])
         self.assertEqual(20, mock_utils_exc.call_count)
 
     # Mock the eventlet.greenthread.sleep for the looping_call
@@ -154,18 +178,20 @@ class DiskPartitionerTestCase(test_base.BaseTestCase):
                                              mock_disk_partitioner_exec):
         dp = disk_partitioner.DiskPartitioner('/dev/fake')
         fake_parts = [(1, {'boot_flag': None,
+                           'extra_flags': None,
                            'fs_type': 'fake-fs-type',
                            'type': 'fake-type',
                            'size': 1}),
                       (2, {'boot_flag': 'boot',
+                           'extra_flags': None,
                            'fs_type': 'fake-fs-type',
                            'type': 'fake-type',
                            'size': 1})]
 
         with mock.patch.object(dp, 'get_partitions', autospec=True) as mock_gp:
             mock_gp.return_value = fake_parts
-            mock_utils_exc.return_value = (None, "Specified filename /dev/fake"
-                                                 " does not exist.")
+            mock_utils_exc.return_value = ('', "Specified filename /dev/fake"
+                                               " does not exist.")
             self.assertRaises(exception.InstanceDeployFailure, dp.commit)
 
         mock_disk_partitioner_exec.assert_called_once_with(
@@ -174,5 +200,6 @@ class DiskPartitionerTestCase(test_base.BaseTestCase):
             'mkpart', 'fake-type', 'fake-fs-type', '2', '3',
             'set', '2', 'boot', 'on')
         mock_utils_exc.assert_called_with(
-            'fuser', '/dev/fake', run_as_root=True, check_exit_code=[0, 1])
+            'fuser', '/dev/fake', run_as_root=True,
+            check_exit_code=[0, 1])
         self.assertEqual(20, mock_utils_exc.call_count)
